@@ -5,17 +5,8 @@ from Products.Five.testbrowser import Browser
 from euphorie.client.tests.utils import addSurvey
 
 class CountryTests(EuphorieFunctionalTestCase):
-    def register(self, browser):
-        # If this getLink failed the translations may not be compiled yet. This
-        # can happen if you run tests without ever having started Zope.
-        browser.getLink("Registreer").click()
-        browser.getControl(name="email").value="guest"
-        browser.getControl(name="password1:utf8:ustring").value="guest"
-        browser.getControl(name="password2:utf8:ustring").value="guest"
-        browser.getControl(name="next", index=1).click()
-
-
     def testSessionFiltersByLanguage(self):
+        from euphorie.client.tests.utils import registerUserInClient
         survey="""<sector xmlns="http://xml.simplon.biz/euphorie/survey/1.0">
                     <title>Sector</title>
                     <survey>
@@ -36,7 +27,7 @@ class CountryTests(EuphorieFunctionalTestCase):
         browser=Browser()
         browser.open(self.portal.client.absolute_url())
         browser.getLink("Nederlands", index=1).click()
-        self.register(browser)
+        registerUserInClient(browser, link="Registreer")
         self.assertEqual(browser.url, "http://nohost/plone/client/nl/?language=nl-NL")
         self.assertEqual(browser.getControl(name="survey").options,
                 ["branche/vragenlijst"])
