@@ -3,7 +3,9 @@
 def addAccount(login="jane@example.com", password=u"Øle"):
     from z3c.saconfig import Session
     from euphorie.client import model
-    account=model.Account(loginname="jane@example.com", password=u"Øle")
+    from euphorie.client import CONDITIONS_VERSION
+    account=model.Account(loginname="jane@example.com", password=u"Øle",
+            tc_approved=CONDITIONS_VERSION)
     session=Session()
     session.add(account)
     session.flush()
@@ -42,4 +44,7 @@ def registerUserInClient(browser, link="register"):
     browser.getControl(name="password1:utf8:ustring").value="guest"
     browser.getControl(name="password2:utf8:ustring").value="guest"
     browser.getControl(name="next", index=1).click()
+    # XXX Why does this not always happen??
+    if "terms-and-conditions" in browser.url:
+        browser.getForm().submit()
 
